<h1 align="center">kilroyplot</h1>

<div align="center">

kilroy plot styling 📊

[![Tests](https://github.com/kilroybot/kilroyplot/actions/workflows/test-multiplatform.yml/badge.svg)](https://github.com/kilroybot/kilroyplot/actions/workflows/test-multiplatform.yml)

</div>

---

kilroy plot styling 📊

## Installing

Using `pip`:

```sh
pip install kilroyplot
```

## Usage

Just import and use the same as with `matplotlib`:

```python
from kilroyplot.plot import plt
```
